==> amity-sdk-6.43.0-sources.jar: main/com/amity/socialcloud/sdk/core/domain/session/LoginUseCase.kt <==
package com.amity.socialcloud.sdk.core.domain.session

import com.amity.socialcloud.sdk.core.data.session.SessionLocalDataStore
import com.amity.socialcloud.sdk.core.data.session.SessionRepository
import com.amity.socialcloud.sdk.core.session.eventbus.AppEventBus
import com.amity.socialcloud.sdk.core.session.eventbus.SessionLifeCycleEventBus
import com.amity.socialcloud.sdk.core.session.model.AppEvent
import com.amity.socialcloud.sdk.core.session.model.SessionLifeCycle
import com.ekoapp.ekosdk.internal.data.EkoDatabase
import com.ekoapp.ekosdk.internal.data.model.EkoAccount
import io.reactivex.rxjava3.core.Single

internal class LoginUseCase {

    fun execute(
        appEventBus: AppEventBus?,
        sessionLifeCycleEventBus: SessionLifeCycleEventBus?,
        userId: String, displayName: String?, authToken: String?,
        isLegacyVersion: Boolean
    ): Single<EkoAccount> {
        verifyUserId(
            appEventBus = appEventBus,
            userId = userId
        )
        appEventBus?.publish(AppEvent.LoggingIn)
        return SessionRepository().login(
            userId = userId,
            displayName = displayName,
            authToken = authToken,
            isLegacyVersion = isLegacyVersion
        )
            .andThen(
                SessionRepository().getCurrentAccount()
            )
            .doOnSuccess {
                appEventBus?.publish(AppEvent.LoginSuccess)
                sessionLifeCycleEventBus?.publish(SessionLifeCycle.Establish(it))
            }
            .doOnError {
                appEventBus?.publish(AppEvent.LoginFail)
            }
    }

    private fun verifyUserId(
        appEventBus: AppEventBus?,
        userId: String
    ) {
        val currentUserId = ActiveUserIdGetUseCase().execute()
        if (currentUserId.isNotEmpty() && userId != currentUserId) {
            appEventBus?.publish(AppEvent.ManualLogout)
        }
    }
}

==> amity-sdk-6.47.0-sources.jar: main/com/amity/socialcloud/sdk/core/domain/session/LoginUseCase.kt <==
package com.amity.socialcloud.sdk.core.domain.session

import com.amity.socialcloud.sdk.core.data.session.SessionLocalDataStore
import com.amity.socialcloud.sdk.core.data.session.SessionRepository
import com.amity.socialcloud.sdk.core.session.eventbus.AppEventBus
import com.amity.socialcloud.sdk.core.session.eventbus.SessionLifeCycleEventBus
import com.amity.socialcloud.sdk.core.session.model.AppEvent
import com.amity.socialcloud.sdk.core.session.model.SessionLifeCycle
import com.amity.socialcloud.sdk.model.core.error.AmityError
import com.amity.socialcloud.sdk.model.core.error.AmityException
import com.ekoapp.ekosdk.internal.data.EkoDatabase
import com.ekoapp.ekosdk.internal.data.model.EkoAccount
import io.reactivex.rxjava3.core.Single

internal class LoginUseCase {

    fun execute(
        appEventBus: AppEventBus?,
        sessionLifeCycleEventBus: SessionLifeCycleEventBus?,
        userId: String, displayName: String?, authToken: String?,
        isLegacyVersion: Boolean
    ): Single<EkoAccount> {
        verifyUserId(
            appEventBus = appEventBus,
            userId = userId
        )
        appEventBus?.publish(AppEvent.LoggingIn)
        return SessionRepository().login(
            userId = userId,
            displayName = displayName,
            authToken = authToken,
            isLegacyVersion = isLegacyVersion
        )
            .andThen(
                SessionRepository().getCurrentAccount()
            )
            .doOnSuccess {
                appEventBus?.publish(AppEvent.LoginSuccess)
                sessionLifeCycleEventBus?.publish(SessionLifeCycle.Establish(it))
            }
            .doOnError {
                val amityError = AmityException.fromThrowable(it)
                if (amityError.code == AmityError.USER_IS_GLOBAL_BANNED.code ||
                    amityError.code == AmityError.UNAUTHORIZED_ERROR.code
                ) {
                    appEventBus?.publish(AppEvent.TerminationCodeReceive(amityError))
                } else {
                    appEventBus?.publish(AppEvent.LoginFail)
                }
            }
    }

    private fun verifyUserId(
        appEventBus: AppEventBus?,
        userId: String
    ) {
        val currentUserId = ActiveUserIdGetUseCase().execute()
        if (currentUserId.isNotEmpty() && userId != currentUserId) {
            appEventBus?.publish(AppEvent.ManualLogout)
        }
    }
}
